@@ -1,6 +1,6 @@
 
 from bciavm.pipelines.components.transformers import Transformer
-
+from bciavm.utils.bci_utils import preprocess_data
 import pandas as pd
 
 class PreprocessTransformer(Transformer) :
@@ -147,7 +147,7 @@ class PreprocessTransformer(Transformer) :
         Returns:
             ww.DataTable: Transformed X
         """
-        X_t = bciavm.utils.bci_utils.preprocess_data(X, drop_outliers=False, split_data=False)
+
         X_t = self.merge_tables(X)
         X_t = self._calc_aggregates(X_t)
         # X_t = X_t[[col for col in X_t.columns if 'POSTTOWN' not in col and 'POSTCODE' not in col and 'unit_indx' not in col]]
